summaryrefslogtreecommitdiffstats
path: root/kmail/main.cpp
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-11-10 17:12:56 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-11-19 22:35:18 +0900
commit74926683f153c10d642dd7b330e90d1518ccd088 (patch)
tree502eded77b3da5b3fd9ededd4cd6977ddb2c7003 /kmail/main.cpp
parent79908b3926d6e3b676a34ac23faa43a477f75b65 (diff)
downloadtdepim-74926683f153c10d642dd7b330e90d1518ccd088.tar.gz
tdepim-74926683f153c10d642dd7b330e90d1518ccd088.zip
Rename KUniqueApplication to TDEUniqueApplication
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kmail/main.cpp')
-rw-r--r--kmail/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/main.cpp b/kmail/main.cpp
index 8b40e555e..fe5dee0a6 100644
--- a/kmail/main.cpp
+++ b/kmail/main.cpp
@@ -19,7 +19,7 @@
*/
#include <config.h>
-#include <kuniqueapplication.h>
+#include <tdeuniqueapplication.h>
#include <tdeglobal.h>
#include <knotifyclient.h>
#include <dcopclient.h>
@@ -36,10 +36,10 @@
//-----------------------------------------------------------------------------
-class KMailApplication : public KUniqueApplication
+class KMailApplication : public TDEUniqueApplication
{
public:
- KMailApplication() : KUniqueApplication() { };
+ KMailApplication() : TDEUniqueApplication() { };
virtual int newInstance();
void commitData(TQSessionManager& sm);
@@ -66,7 +66,7 @@ int KMailApplication::newInstance()
int main(int argc, char *argv[])
{
// WABA: KMail is a KUniqueApplication. Unfortunately this makes debugging
// a bit harder: You should pass --nofork as commandline argument when using
// a debugger. In gdb you can do this by typing "set args --nofork" before
// typing "run".
@@ -66,7 +66,7 @@ int KMailApplication::newInstance()
int main(int argc, char *argv[])
{
- // WABA: KMail is a KUniqueApplication. Unfortunately this makes debugging
+ // WABA: KMail is a TDEUniqueApplication. Unfortunately this makes debugging
// a bit harder: You should pass --nofork as commandline argument when using
// a debugger. In gdb you can do this by typing "set args --nofork" before